@@ -133,17 +133,6 @@ class CCompiler(object):
                 if sys.platform != 'darwin':
                     args.append('-Wl,--no-as-needed')
 
-        for library in libraries + extra_libraries:
-            if self.check_is_msvc():
-                # Note that Visual Studio builds do not use libtool!
-                if library != 'm':
-                    args.append(library + '.lib')
-            else:
-                if library.endswith(".la"):  # explicitly specified libtool library
-                    args.append(library)
-                else:
-                    args.append('-l' + library)
-
         for library_path in libpaths:
             # The dumper program needs to look for dynamic libraries
             # in the library paths first
@@ -161,6 +150,18 @@ class CCompiler(object):
 
             runtime_paths.append(library_path)
 
+        for library in libraries + extra_libraries:
+            if self.check_is_msvc():
+                # Note that Visual Studio builds do not use libtool!
+                if library != 'm':
+                    args.append(library + '.lib')
+            else:
+                # If we get a real filename, just use it as-is
+                if library.endswith(".la") or os.path.isfile(library):
+                    args.append(library)
+                else:
+                    args.append('-l' + library)
+
         for envvar in runtime_path_envvar:
             if envvar in os.environ:
                 os.environ[envvar] = \
@@ -212,8 +213,6 @@ class CCompiler(object):
     def compile(self, pkg_config_cflags, cpp_includes, source, init_sections):
         extra_postargs = []
         includes = []
-        source_str = ''.join(source)
-        tmpdir_idx = source_str.rfind(os.sep, 0, source_str.rfind(os.sep))
         (include_paths, macros, extra_args) = \
             self._set_cpp_options(pkg_config_cflags)
 
