@@ -26,7 +26,6 @@ from __future__ import unicode_literals
 import os
 import sys
 import tempfile
-import shutil
 import subprocess
 from xml.etree.cElementTree import parse
 
@@ -89,12 +88,12 @@ class GDumpParser(object):
         """
 
         # First pass: parsing
-        for node in self._namespace.values():
+        for node in list(self._namespace.values()):
             if isinstance(node, ast.Function):
                 self._initparse_function(node)
 
         if self._namespace.name == 'GObject' or self._namespace.name == 'GLib':
-            for node in self._namespace.values():
+            for node in list(self._namespace.values()):
                 if isinstance(node, ast.Record):
                     self._initparse_gobject_record(node)
 
@@ -123,7 +122,7 @@ class GDumpParser(object):
         # Pair up boxed types and class records
         for name, boxed in self._boxed_types.items():
             self._pair_boxed_type(boxed)
-        for node in self._namespace.values():
+        for node in list(self._namespace.values()):
             if isinstance(node, (ast.Class, ast.Interface)):
                 self._find_class_record(node)
 
@@ -162,6 +161,12 @@ blob containing data gleaned from GObject's primitive introspection."""
         out_path = os.path.join(self._binary.tmpdir, 'dump.xml')
 
         args = []
+
+        # Prepend the launcher command and arguments, if defined
+        launcher = os.environ.get('GI_CROSS_LAUNCHER')
+        if launcher:
+            args.extend(launcher.split())
+
         args.extend(self._binary.args)
         args.append('--introspect-dump=%s,%s' % (in_path, out_path))
 
@@ -175,7 +180,7 @@ blob containing data gleaned from GObject's primitive introspection."""
             return parse(out_path)
         finally:
             if not utils.have_debug_flag('save-temps'):
-                shutil.rmtree(self._binary.tmpdir)
+                utils.rmtree(self._binary.tmpdir)
 
     # Parser
 
